==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class PlanWsparciaRealizacja extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_REALIZACJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikId;

    /**
     * PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataRealizacji;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataRealizacji() {
        return dataRealizacji;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     *
     * @param dataRealizacji
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataRealizacji(Date dataRealizacji) {
        this.dataRealizacji = dataRealizacji;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaRealizacja other = (PlanWsparciaRealizacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getDataRealizacji() == null ? other.getDataRealizacji() == null : this.getDataRealizacji().equals(other.getDataRealizacji()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getDataRealizacji() == null) ? 0 : getDataRealizacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", dataRealizacji=").append(dataRealizacji);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/PlanWsparciaRealizacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class PlanWsparciaRealizacja extends GenericDPSObject {
    /**
     * PLAN_WSPARCIA_REALIZACJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikId;

    /**
     * PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataRealizacji;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikId() {
        return pracownikId;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.PRACOWNIK_ID
     *
     * @param pracownikId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikId(Long pracownikId) {
        this.pracownikId = pracownikId;
    }

    /**
     * @return PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataRealizacji() {
        return dataRealizacji;
    }

    /**
     * PLAN_WSPARCIA_REALIZACJA.DATA_REALIZACJI
     *
     * @param dataRealizacji
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataRealizacji(Date dataRealizacji) {
        this.dataRealizacji = dataRealizacji;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        PlanWsparciaRealizacja other = (PlanWsparciaRealizacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikId() == null ? other.getPracownikId() == null : this.getPracownikId().equals(other.getPracownikId()))
            && (this.getDataRealizacji() == null ? other.getDataRealizacji() == null : this.getDataRealizacji().equals(other.getDataRealizacji()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikId() == null) ? 0 : getPracownikId().hashCode());
        result = prime * result + ((getDataRealizacji() == null) ? 0 : getDataRealizacji().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikId=").append(pracownikId);
        sb.append(", dataRealizacji=").append(dataRealizacji);
        sb.append("]");
        return sb.toString();
    }
}
